#include <QtQuick>
#ifdef QT_QML_DEBUG
#include <QDebug>
#endif

#include <sailfishapp.h>

#include "journey.h"
#include "journeymodel.h"
#include "statsmodel.h"
#include "status.h"
#include "settings.h"
#include "imageprovider.h"
#include "graph.h"
#include "statsweekdayave.h"
#include "statshourjourneys.h"
#include "statsweekdaycongestion.h"
#include "statshourcongestion.h"
#include "statsyearjourneys.h"
#include "statsyearduration.h"

#include "harbour-pedalo.h"

int main(int argc, char *argv[])
{
    // SailfishApp::main() will display "qml/harbour-pedalo.qml", if you need more
    // control over initialization, you can use:
    //
    //   - SailfishApp::application(int, char *[]) to get the QGuiApplication *
    //   - SailfishApp::createView() to get a new QQuickView * instance
    //   - SailfishApp::pathTo(QString) to get a QUrl to a resource file
    //   - SailfishApp::pathToMainQml() to get a QUrl to the main QML file
    //
    // To display the view, call "show()" (will show fullscreen on device).

    QScopedPointer<QGuiApplication> app(SailfishApp::application(argc, argv));
    // These values are used by QSettings to access the config file in
    // /home/nemo/.local/share/flypig/harbour-pedalo.conf
    //QCoreApplication::setOrganizationName("flypig");
    QCoreApplication::setOrganizationDomain("www.flypig.co.uk");
    QCoreApplication::setApplicationName(APP_NAME);

    Settings::instantiate();
    qmlRegisterSingletonType<Settings>("harbour.pedalo.settings", 1, 0, "Settings", Settings::provider);
    qmlRegisterType<JourneyModel>("harbour.pedalo.journeymodel", 1, 0, "JourneyModel");
    qmlRegisterType<Graph>("harbour.pedalo.graph", 1, 0, "Graph");

    JourneyModel journeys;
    Status currentStatus(journeys);
    Settings::getInstance().setMainStatus(currentStatus);
    Settings::getInstance().loadSettings();

    StatsModel statsmodel;

    StatsYearDuration statsyearduration(&journeys);
    statsmodel.addStats(statsyearduration);

    StatsYearJourneys statsyearjourneys(&journeys);
    statsmodel.addStats(statsyearjourneys);

    StatsWeekdayAve statsweekdayave(&journeys);
    statsmodel.addStats(statsweekdayave);

    StatsHourJourneys statshourjourneys(&journeys);
    statsmodel.addStats(statshourjourneys);

    StatsWeekdayCongestion statsweekdaycongestion(&journeys);
    statsmodel.addStats(statsweekdaycongestion);

    StatsHourCongestion statshourcongestion(&journeys);
    statsmodel.addStats(statshourcongestion);

    QFile file;
    file.setFileName(Settings::getConfigDir() + "/journeys.csv");
    journeys.importFromFile(file);
    journeys.sort(JourneyModel::StartRole, Qt::DescendingOrder);

    QScopedPointer<QQuickView> view(SailfishApp::createView());
    view->engine()->addImageProvider(QLatin1String("pedalo"), new ImageProvider(Settings::getInstance()));
    view->setSource(SailfishApp::pathTo("qml/harbour-pedalo.qml"));

    QQmlContext *ctxt = view->rootContext();
    ctxt->setContextProperty("version", VERSION);
    qDebug() << "harbour-pedalo VERSION string: " << VERSION;
    qDebug() << "VERSION_MAJOR: " << VERSION_MAJOR;
    qDebug() << "VERSION_MINOR: " << VERSION_MINOR;
    qDebug() << "VERSION_BUILD: " << VERSION_BUILD;

    ctxt->setContextProperty("journeymodel", &journeys);
    ctxt->setContextProperty("currentStatus", &currentStatus);
    ctxt->setContextProperty("statsmodel", &statsmodel);

    view->show();
    int result = app->exec();

    // Write out the journey data
    QDir dir;
    dir.mkpath(Settings::getConfigDir());
    file.setFileName(Settings::getConfigDir() + "/journeys.csv");
    qDebug() << "File saved as: " << file.fileName();
    journeys.exportToFile(file);

    Settings::getInstance().saveSettings();

    return result;
}
