#include "statshourjourneys.h"

#define LOWESTHOUR (7)
#define HIGHESTHOUR (21)

StatsHourJourneys::StatsHourJourneys(JourneyModel * journeys) :
    journeys(journeys)
{
    title = "Journey proportion per hour (%)";
    units = "%";

    labels.clear();
    for (int hour = LOWESTHOUR; hour <= HIGHESTHOUR; hour++) {
        labels << QString::number(hour);
    }
}

void StatsHourJourneys::update() {
    unsigned int minsperhour[24];
    quint64 totalmins;
    int pos;

    barvalues.clear();

    for (pos = 0; pos < 24; pos++) {
        minsperhour[pos] = 0u;
    }

    totalmins = 0u;
    foreach (Journey const &journey, journeys->getData()) {
        QTime time = journey.getStartTime();
        int hour = time.hour();
        int startmin = time.minute();
        int remaining = (journey.getDuration() / 60);
        totalmins += remaining;

        while (remaining > 0) {
            // toadd is always greater than 0, so the loop is guaranteed to exit
            unsigned int toadd = (startmin + remaining) < 60 ? remaining : 60 - startmin;
            minsperhour[hour] += toadd;
            remaining -= toadd;
            startmin = 0;

            hour = (hour + 1) % 24;
        }
    }

    for (pos = LOWESTHOUR; pos <= HIGHESTHOUR; pos++) {
        float result = 0.0f;
        if (totalmins > 0) {
            result = ((double)minsperhour[pos] / (double)totalmins);
        }
        barvalues << result;
    }
}
