#include "statsweekdaycongestion.h"

StatsWeekdayCongestion::StatsWeekdayCongestion(JourneyModel * journeys) :
    journeys(journeys)
{
    title = "Congestion by day (cycles per hour)";
    units = "";
    labels = QStringList{"M", "T", "W", "Th", "F", "S", "Su"};
}

void StatsWeekdayCongestion::update() {
    double passed[7];
    unsigned int count[7];
    int pos;

    barvalues.clear();

    for (pos = 0; pos < 7; pos++) {
        passed[pos] = 0u;
        count[pos] = 0u;
    }

    foreach (Journey const &journey, journeys->getData()) {
        QDate date = journey.getStartDate();
        int dayofweek = date.dayOfWeek() - 1;
        double duration = journey.getDuration() / (60.0 * 60.0);
        if (dayofweek >= 0) {
            passed[dayofweek] += (journey.getOvertook() + journey.getOvertakenBy()) / duration;
            count[dayofweek]++;
        }
    }

    maxval = 0.0;
    for (pos = 0; pos < 7; pos++) {
        float result = 0.0f;
        if (count[pos] > 0) {
            result = ((double)passed[pos] / (double)count[pos]);
        }
        if (result > maxval) {
            maxval = result;
        }
        barvalues << result;
    }

    step = maxval > 5.0 ? qRound(maxval / 5.0) : (maxval / 5.0);
}
